package com.example.PhidgetHelloWorld;

import android.app.Activity;
import android.os.Bundle;
import android.widget.TextView;

import com.phidgets.*;
import com.phidgets.event.*;

public class HelloWorldActivity extends Activity {

	Manager device;
	
	TextView eventOutput;
	
	/** Called when the activity is first created. */
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.main);
        
        try
        {
	        com.phidgets.usb.Manager.Initialize(this);
        	
        	device = new Manager();
        	
        	eventOutput = (TextView)findViewById(R.id.eventResultContainer);
			
			device.addAttachListener(new AttachListener() {
				public void attached(final AttachEvent attachEvent) {
					AttachEventHandler handler = new AttachEventHandler(attachEvent.getSource(), eventOutput);
					// This is synchronised in case more than one device is attached before one completes attaching
					synchronized(handler) {
						runOnUiThread(handler);
						try {
							handler.wait();
						} catch (InterruptedException e) {
							e.printStackTrace();
						}
					}
				}
			});
			
			device.addDetachListener(new DetachListener() {
				public void detached(final DetachEvent detachEvent) {
					DetachEventHandler handler = new DetachEventHandler(detachEvent.getSource(), eventOutput);
					// This is synchronised in case more than one device is attached before one completes attaching
					synchronized(handler) {
						runOnUiThread(handler);
						try {
							handler.wait();
						} catch (InterruptedException e) {
							e.printStackTrace();
						}
					}
				}
			});

			device.open();
        } catch (PhidgetException pe) {
	        pe.printStackTrace();
		}
        
    }
    
    class AttachEventHandler implements Runnable { 
    	Phidget device; 
    	TextView eventOutput;

		public AttachEventHandler(Phidget device, TextView eventOutput) {
			this.device = device;
			this.eventOutput = eventOutput;
		}

		public void run() {
			try {
				eventOutput.setText("Hello " + device.getDeviceName() + ", Serial " + Integer.toString(device.getSerialNumber()));
			} catch (PhidgetException e) {
				e.printStackTrace();
			}
        
	    	// Notify that we're done
	    	synchronized(this) {
	    		this.notify();
	    	}
		}
    }
    
    class DetachEventHandler implements Runnable {
    	Phidget device;
    	TextView eventOutput;
    	
    	public DetachEventHandler(Phidget device, TextView eventOutput) {
    		this.device = device;
    		this.eventOutput = eventOutput;
    	}
    	
		public void run() {
			try {
				eventOutput.setText("Goodbye " + device.getDeviceName() + ", Serial " + Integer.toString(device.getSerialNumber()));
			} catch (PhidgetException e) {
				e.printStackTrace();
			}
        
	    	// Notify that we're done
	    	synchronized(this) {
	    		this.notify();
	    	}
		}
    }

    @Override
    protected void onDestroy() {
    	super.onDestroy();
    	try {
			device.close();
		} catch (PhidgetException e) {
			e.printStackTrace();
		}
    	com.phidgets.usb.Manager.Uninitialize();
    }    
}
