package com.phidgets.SpatialUSB;

import com.phidgets.Phidget;
import com.phidgets.PhidgetException;
import com.phidgets.SpatialPhidget;
import com.phidgets.event.AttachEvent;
import com.phidgets.event.AttachListener;
import com.phidgets.event.DetachEvent;
import com.phidgets.event.DetachListener;
import com.phidgets.event.SpatialDataEvent;
import com.phidgets.event.SpatialDataListener;

import android.app.Activity;
import android.os.Bundle;
import android.widget.TextView;

public class SpatialUSBExampleActivity extends Activity {
	SpatialPhidget spatial;
	
	TextView[] accelTextViews;
	
    /** Called when the activity is first created. */
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.main);
        
        accelTextViews = new TextView[8];
        accelTextViews[0] = (TextView)findViewById(R.id.accel0);
        accelTextViews[1] = (TextView)findViewById(R.id.accel1);
        accelTextViews[2] = (TextView)findViewById(R.id.accel2);
        
        try
        {
	        com.phidgets.usb.Manager.Initialize(this);
			spatial = new SpatialPhidget();
			spatial.addAttachListener(new AttachListener() {
				public void attached(final AttachEvent ae) {
					AttachDetachRunnable handler = new AttachDetachRunnable(ae.getSource(), true);
					synchronized(handler)
					{
						runOnUiThread(handler);
						try {
							handler.wait();
						} catch (InterruptedException e) {
							e.printStackTrace();
						}
					}
				}
			});
			spatial.addDetachListener(new DetachListener() {
				public void detached(final DetachEvent ae) {
					AttachDetachRunnable handler = new AttachDetachRunnable(ae.getSource(), false);
					synchronized(handler)
					{
						runOnUiThread(handler);
						try {
							handler.wait();
						} catch (InterruptedException e) {
							e.printStackTrace();
						}
					}
				}
			});
			spatial.addSpatialDataListener(new SpatialDataListener() {
				public void data(SpatialDataEvent sde) {
					runOnUiThread(new SpatialDataRunnable(
							sde.getData()[0].getAcceleration()[0],
							sde.getData()[0].getAcceleration()[1],
							sde.getData()[0].getAcceleration()[2]));
				}
			});
			spatial.openAny();
		}
		catch (PhidgetException pe)
		{
	        pe.printStackTrace();
		}
    }
    
    @Override
    protected void onDestroy() {
    	super.onDestroy();
    	try {
			spatial.close();
		} catch (PhidgetException e) {
			e.printStackTrace();
		}
    	com.phidgets.usb.Manager.Uninitialize();
    }
    
	class AttachDetachRunnable implements Runnable {
		Phidget phidget;
		boolean attach;
		public AttachDetachRunnable(Phidget phidget, boolean attach)
		{
			this.phidget = phidget;
			this.attach = attach;
		}
		public void run() {
			TextView attachedTxt = (TextView) findViewById(R.id.attachedTxt);
	        if(attach)
	        {
	        	attachedTxt.setText("Attached");
	        	try {
	    	        TextView nameTxt = (TextView) findViewById(R.id.nameTxt);
	    	        TextView serialTxt = (TextView) findViewById(R.id.serialTxt);
	    	        TextView versionTxt = (TextView) findViewById(R.id.versionTxt);
	    	        TextView labelTxt = (TextView) findViewById(R.id.labelTxt);
	    	        
	    	        nameTxt.setText(phidget.getDeviceName());
	    	        serialTxt.setText(Integer.toString(phidget.getSerialNumber()));
	    	        versionTxt.setText(Integer.toString(phidget.getDeviceVersion()));
	    	        labelTxt.setText(phidget.getDeviceLabel());
	    	        
	    	        //Slow down data rate so it looks ok on the GUI
	    	        ((SpatialPhidget)phidget).setDataRate(128);
				} catch (PhidgetException e) {
					e.printStackTrace();
				}
	        }
	        else
	        	attachedTxt.setText("Detached");
        	//notify that we're done
        	synchronized(this)
        	{
        		this.notify();
        	}
	    }
	}

	class SpatialDataRunnable implements Runnable {
		double ax, ay, az;
		public SpatialDataRunnable(double ax, double ay, double az)
		{
			this.ax = ax;
			this.ay = ay;
			this.az = az;
		}
		public void run() {
			if(accelTextViews[0]!=null)
				accelTextViews[0].setText("0: "+ax);
			if(accelTextViews[1]!=null)
				accelTextViews[1].setText("1: "+ay);
			if(accelTextViews[2]!=null)
				accelTextViews[2].setText("2: "+az);
	    }
	}
}